==> mandrel-23.0.0.0-Final.tar.gz: mandrel-mandrel-23.0.0.0-Final/substratevm/src/com.oracle.svm.agent/src/com/oracle/svm/agent/ignoredconfig/AgentMetaInfProcessor.java <==
/*
 * Copyright (c) 2021, 2021, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */
package com.oracle.svm.agent.ignoredconfig;

import java.nio.file.Path;

import com.oracle.svm.configure.config.ConfigurationFileCollection;
import com.oracle.svm.driver.metainf.MetaInfFileType;
import com.oracle.svm.driver.metainf.NativeImageMetaInfResourceProcessor;

public class AgentMetaInfProcessor implements NativeImageMetaInfResourceProcessor {

    private final ConfigurationFileCollection ignoredConfigFileCollection;

    public AgentMetaInfProcessor(ConfigurationFileCollection ignoredConfigFileCollection) {
        this.ignoredConfigFileCollection = ignoredConfigFileCollection;
    }

    @Override
    public void processMetaInfResource(Path classpathEntry, Path resourceRoot, Path resourcePath, MetaInfFileType type) throws Exception {
        ignoredConfigFileCollection.addDirectory(resourcePath.getParent());
    }

    @Override
    public void showWarning(String message) {
    }

    @Override
    public void showVerboseMessage(String message) {
    }

    @Override
    public boolean isExcluded(Path resourcePath, Path classpathEntry) {
        return false;
    }
}

==> mandrel-23.1.5.0-Final.tar.gz: mandrel-mandrel-23.1.5.0-Final/substratevm/src/com.oracle.svm.agent/src/com/oracle/svm/agent/ignoredconfig/AgentMetaInfProcessor.java <==
/*
 * Copyright (c) 2021, 2021, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */
package com.oracle.svm.agent.ignoredconfig;

import java.nio.file.Path;

import com.oracle.svm.configure.config.ConfigurationFileCollection;
import com.oracle.svm.driver.metainf.MetaInfFileType;
import com.oracle.svm.driver.metainf.NativeImageMetaInfResourceProcessor;

public class AgentMetaInfProcessor implements NativeImageMetaInfResourceProcessor {

    private final ConfigurationFileCollection ignoredConfigFileCollection;

    public AgentMetaInfProcessor(ConfigurationFileCollection ignoredConfigFileCollection) {
        this.ignoredConfigFileCollection = ignoredConfigFileCollection;
    }

    @Override
    public boolean processMetaInfResource(Path classpathEntry, Path resourceRoot, Path resourcePath, MetaInfFileType type) throws Exception {
        ignoredConfigFileCollection.addDirectory(resourcePath.getParent());
        return false;
    }

    @Override
    public void showWarning(String message) {
    }

    @Override
    public void showVerboseMessage(String message) {
    }

    @Override
    public boolean isExcluded(Path resourcePath, Path classpathEntry) {
        return false;
    }
}
